@@ -4,8 +4,7 @@
  * SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
  */
 
-#ifndef KGAPI_FAKEAUTHBROWSER_H_
-#define KGAPI_FAKEAUTHBROWSER_H_
+#pragma once
 
 #include <QScopedPointer>
 
@@ -21,5 +20,4 @@ private:
     friend class Private;
 };
 
-#endif
 
