@@ -10,7 +10,7 @@
 #include "calendarservice.h"
 #include "account.h"
 #include "calendar.h"
-#include "../debug.h"
+#include "debug.h"
 #include "private/queuehelper_p.h"
 
 #include <QNetworkRequest>
